@@ -24,6 +24,7 @@ class Course(models.Model):
     shortname = models.CharField(max_length=20)
     filename = models.CharField(max_length=200)
     badge_icon = models.FileField(upload_to="badges",blank=True, default=None)
+    staff_only = models.BooleanField(default=False)
    
     class Meta:
         verbose_name = _('Course')
@@ -178,6 +179,7 @@ class Activity(models.Model):
     title = models.TextField(blank=False)
     type = models.CharField(max_length=10)
     digest = models.CharField(max_length=100)
+    baseline = models.BooleanField(default=False)
     
     def __unicode__(self):
         return self.get_title()
@@ -268,7 +270,7 @@ class Tracker(models.Model):
  
     @staticmethod
     def has_completed_trackers(course,user):
-        count = Tracker.objects.filter(user=user, course=course,completed=True).count()
+        count = Tracker.objects.filter(user=user, course=course,completed=True).count()        
         if count > 0:
             return True
         return False
